<?php

if (!defined('_PS_VERSION_'))
	exit;

class BlockProductCount extends Module
{
	public function __construct()
	{
		$this->name = 'blockproductcount';
		$this->tab = 'front_office_features';
		$this->version = 0.3;
		$this->author = 'www.megventure.com';
		$this->bootstrap = true;						
		$this->need_instance = 0;
		
		$config = Configuration::getMultiple(array($this->name.'_cmslink', $this->name.'_customlink'));
		if (isset($config[$this->name.'_cmslink']))
			$this->cmslink = $config[$this->name.'_cmslink'];
		if (isset($config[$this->name.'_customlink']))
			$this->customlink = $config[$this->name.'_customlink'];

		parent::__construct();
		
		$this->displayName = $this->l('Block product count');
		$this->description = $this->l('Adds a block to display the size of inventory.');
		
	}

	public function install()
	{
		$path = Tools::getShopDomain(true);
		Configuration::updateValue($this->name.'_cmslink', 0);
		Configuration::updateValue($this->name.'_customlink', $path);
		if (!parent::install())
			return false;
		if (!$this->registerHook('leftColumn'))
			return false;
		return true;
	}
	
	public function uninstall()
	{
		if (!Configuration::deleteByName($this->name.'_cmslink')
			OR !Configuration::deleteByName($this->name.'_customlink')
			OR !parent::uninstall())
		return false;
	return true;
	}

	public function getContent()
	{
		global $cookie;

		$html = '
		<h2>'.$this->l('Block Product Count').'</h2>
		';
		
		if (Tools::isSubmit('submitConfiguration'))
			if (Validate::isUnsignedInt(Tools::getValue('id_cms')))
			{
				Configuration::updateValue($this->name.'_cmslink', (int)(Tools::getValue('id_cms')));
				Configuration::updateValue($this->name.'_customlink', Tools::getValue('custom_link'));
				$html .= $this->displayConfirmation($this->l('Settings are updated'));
			}
		
		$cmss = CMS::listCms((int)($cookie->id_lang));
		
		if (!sizeof($cmss))
			$html .= $this->displayError($this->l('No CMS page is available'));
		else
		{
			$html .= '
			<form action="'.Tools::safeOutput($_SERVER['REQUEST_URI']).'" method="post">
				<fieldset>
					<legend><img src="'.$this->_path.'/logo.gif" alt="" /> '.$this->l('Configure').'</legend>
					<label>'.$this->l('Page CMS for link').':</label>
					<div class="margin-form">
						<select name="id_cms"><option value="0">('.$this->l('Select a page').')</option>';
			foreach ($cmss as $cms)
				$html .= '<option value="'.$cms['id_cms'].'"'.(Configuration::get($this->name.'_cmslink') == $cms['id_cms'] ? ' selected="selected"' : '').'>'.$cms['meta_title'].'</option>';
			$html .= '</select>
					</div>
			
			<label>'.$this->l('Custom link').'</label>
			<div class="margin-form">
				<input type="text" name="custom_link" value="'.Configuration::get($this->name.'_customlink').'"/>
				<br>'.$this->l('This is the link where the click on the product count will be redirected. If not empty, this link has priority over the CMS link. So leave it empty if you want to use the assigned CMS page link. Ex: http://www.megventure.com').'
			</div>					
					<p class="center"><input class="button" type="submit" name="submitConfiguration" value="'.$this->l('Save settings').'" /></p>
				</fieldset>
			</form>
			';
		}
		return $html;
	}

	public function hookLeftColumn($params)
	{
		$cms = new CMS((int)Configuration::get($this->name.'_cmslink'), (int)$params['cookie']->id_lang);
		
		//$db     = Db::getInstance();                    // Bağlantı kurdum
		$query = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'product WHERE active = 1';  // Sadece Aktif
		$query1 = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'category WHERE active = 1';  // Tüm kategoriler
		$total_products = Db::getInstance()->getValue($query);   // Toplam değeri $total_products değişkenine atadım
		$total_categories = Db::getInstance()->getValue($query1);    // Toplam değeri $total_categories değişkenine atadım	
		
		global $smarty;
		if (_PS_VERSION_ < '1.6') {
		$smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.5/blockproductcount.tpl');		
		} 
		else 
		{
		$this->smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.6/blockproductcount.tpl');				
		}
	}
	
	public function hookRightColumn($params)
	{
		return $this->hookLeftColumn($params);
	}

	public function hookFooter($params)
	{
		$cms = new CMS((int)Configuration::get($this->name.'_cmslink'), (int)$params['cookie']->id_lang);
		
		$query = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'product WHERE active = 1';  // Sadece Aktif
		$query1 = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'category WHERE active = 1';  // Tüm kategoriler
		$total_products = Db::getInstance()->getValue($query);   // Toplam değeri $total_products değişkenine atadım
		$total_categories = Db::getInstance()->getValue($query1);    // Toplam değeri $total_categories değişkenine atadım	
		
		global $smarty;
		if (_PS_VERSION_ < '1.6') {
		$smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.5/blockproductcountfooter.tpl');
		} 
		else 
		{
		$this->smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.6/blockproductcountfooter.tpl');
		}	
	}
	public function hookTop($params)
	{
		$cms = new CMS((int)Configuration::get($this->name.'_cmslink'), (int)$params['cookie']->id_lang);
		
		$query = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'product WHERE active = 1';  // Sadece Aktif
		$query1 = 'SELECT COUNT(*) FROM '._DB_PREFIX_.'category WHERE active = 1';  // Tüm kategoriler
		$total_products = Db::getInstance()->getValue($query);   // Toplam değeri $total_products değişkenine atadım
		$total_categories = Db::getInstance()->getValue($query1);    // Toplam değeri $total_categories değişkenine atadım	
		
		global $smarty;
		if (_PS_VERSION_ < '1.6') {
		$smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.5/blockproductcounttop.tpl');
		} 
		else 
		{
		$this->smarty->assign(array(
		'cms_page_link' => $cms, 
		'custom_page_link' => Configuration::get($this->name.'_custom_link'),
		'total_products'  => $total_products,
		'total_categories'  => $total_categories));
		return $this->display(__FILE__, 'views/templates/front/1.6/blockproductcounttop.tpl');
		}	
	}
}